// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
import { __awaiter } from "tslib";
import { createHash, createHmac } from "crypto";
/**
 * @internal
 * @ignore
 */
export function sha256Digest(body) {
    return __awaiter(this, void 0, void 0, function* () {
        return createHash("sha256")
            .update(body || "")
            .digest("base64");
    });
}
/**
 * @internal
 * @ignore
 */
export function sha256Hmac(secret, stringToSign) {
    return __awaiter(this, void 0, void 0, function* () {
        const decodedSecret = Buffer.from(secret, "base64");
        return createHmac("sha256", decodedSecret)
            .update(stringToSign)
            .digest("base64");
    });
}
//# sourceMappingURL=cryptoHelpers.js.map